# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red hat
%define base_flavor       redhat
%define base_prefix       pki

## Product Definitions
%define base_system       Certificate System
%define base_product      Token Key Service
%define base_component    tks
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_prefix}-%{base_component}
%define base_version      8.1.1
%define base_release      1
%define base_phase        %{nil}
%define base_group        System Environment/Daemons
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Legacy Definitions
%define legacy_prefix     rhpki
%define legacy_name       %{legacy_prefix}-%{base_component}

## Pre & Post Install/Uninstall Scripts Definitions
%define base_user         pkiuser
%define base_uid          17
%define base_gid          17
%define base_instance     /var/lib/%{base_name}

## Helper Definitions
%define pki_jdk           java-devel >= 1:1.6.0
# Override the default 'pki_jdk' on Fedora 8 platforms
%{?fc8:%define pki_jdk    java-devel >= 1.7.0}
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## For PKI version information, ALWAYS refer to the version of the
## Red Hat UI package dependency associated with this Red Hat spec file!
## %define pki_version       %(echo `rpm -q --queryformat '%{VERSION}' %{base_flavor}-%{base_name}-ui`)
## Unfortunately, the previous command does not appear to work from within
## a 'mock' environment, as the invocation of the 'rpm' command attempts
## to find 'redhat-pki-tks-ui' within the 'host' environment running mock
## rather than the 'mock chrooted' environment.  Ergo, we will simply set
## pki_version = base_version.
##
## Note:  The other call to 'rpm' is not used by 'mock' in Brew,
##        since the 'dist' tag is always defined.
##
%define pki_version %{base_version}
%define pki_major_version %(echo `echo %{pki_version} | awk -F. '{ print $1 }'`)
%define pki_minor_version %(echo `echo %{pki_version} | awk -F. '{ print $2 }'`)
%define pki_patch_version %(echo `echo %{pki_version} | awk -F. '{ print $3 }'`)

## Disallow an initial login shell
## NOTE:  SELinux policy requires a shell of /sbin/nologin
%define base_login_shell  /sbin/nologin

## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5, %{base_flavor}-%{base_name}-ui >= 8.1.0, %{base_prefix}-common >= 8.1.0, %{base_prefix}-util >= 8.1.0, %{pki_jdk}, jpackage-utils >= 1.7.3, jss >= 4.2.6-15, tomcatjss >= 1.1.4

## Without Requires something, rpmbuild will abort!
Requires:       %{base_name}-ui, %{base_prefix}-common >= 8.1.0, %{base_prefix}-selinux >= 8.1.0
Provides:       %{legacy_name}
Obsoletes:      %{legacy_name}


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{pki_tks} is an optional PKI subsystem that
manages the master key(s) and the transport key(s) required to generate and
distribute keys for hardware tokens.  %{pki_tks} provides
the security between tokens and an instance of %{pki_tps},
where the security relies upon the relationship between the master key
and the token keys.  A %{pki_tps} communicates with a
%{pki_tks} over SSL using client authentication.

%{pki_tks} helps establish a secure channel (signed and
encrypted) between the token and the %{pki_tps},
provides proof of presence of the security token during enrollment, and
supports key changeover when the master key changes on the
%{pki_tks}.  Tokens with older keys will get new token keys.

Because of the sensitivity of the data that %{pki_tks} manages,
%{pki_tks} should be set up behind the firewall with
restricted access.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
ant -Dspecfile=%{base_name}.spec



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
cd dist/binary
unzip %{name}-%{version}.zip -d ${RPM_BUILD_ROOT}
sed -i 's/^preop.product.version=.*$/preop.product.version=%{pki_version}/' ${RPM_BUILD_ROOT}/usr/share/%{base_prefix}/%{base_component}/conf/CS.cfg
sed -i 's/^cms.version=.*$/cms.version=%{pki_major_version}.%{pki_minor_version}/' ${RPM_BUILD_ROOT}/usr/share/%{base_prefix}/%{base_component}/conf/CS.cfg
cd ${RPM_BUILD_ROOT}/usr/share/java/%{base_prefix}/%{base_component}
mv %{base_component}.jar %{base_component}-%{version}.jar
ln -s %{base_component}-%{version}.jar %{base_component}.jar



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

%pre
if [ `grep -c %{base_user} /etc/group` -eq 0 ] ; then
	echo "Adding default PKI group \"%{base_user}\" (gid=%{base_gid}) to /etc/group."
	groupadd -g %{base_gid} -r %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI group \"%{base_user}\" (gid=random) to /etc/group."
		groupadd %{base_user}
	fi
fi
if [ `grep -c %{base_user} /etc/passwd` -eq 0 ] ; then
	echo "Adding default PKI user \"%{base_user}\" (uid=%{base_uid}) to /etc/passwd."
	useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -u %{base_uid} -r -m %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI user \"%{base_user}\" (uid=random) to /etc/passwd."
		useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -m %{base_user}
	fi
fi
if [ "$1" -gt 1 ]; then
    backup_dir="%{_datadir}/%{base_prefix}/`rpm -q pki-tks|cut -c5-`"
    if [ -e $backup_dir ]; then
        rm -rf $backup_dir
    fi

    cp -rf %{_datadir}/%{base_prefix}/%{base_component}  $backup_dir
fi


## This package currently contains no post-installation process!
#%post


%preun
if [ -d %{base_instance} ] ; then
	echo "WARNING:  The default instance \"%{base_instance}\" was NOT removed!"
	echo ""
	echo "NOTE:  This means that the data in the default instance called"
	echo "       \"%{base_instance}\" will NOT be overwritten once the"
	echo "       \"%{name}\" package is re-installed."
	echo ""
	echo "Shutting down the default instance \"%{base_instance}\""
	echo "PRIOR to uninstalling the \"%{name}\" package:"
	echo ""
	/etc/init.d/%{base_name} stop
fi


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/java/%{base_prefix}/%{base_component}
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/alias
%attr(00660,root,root) %{_datadir}/%{base_prefix}/%{base_component}/conf/CS.cfg
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/conf/[a-z]*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/etc
%attr(00770,root,root) %{_datadir}/%{base_prefix}/%{base_component}/logs/signedAudit
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/setup
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/shared
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/temp
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/webapps
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/work



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Mon Sep 10 2012 Jack Magne <jmagne@rehdat.com> 8.1.1-1
- Bugzilla Bug #854824 - CA instance creation fails on a newly provisioned RHEL 5.9 - 'Could not initialize class java.util.logging.LogManager'.

* Fri Sep 16 2011 Jack Magne <jmagne@redhat.com> 8.1.0-8
- Bugzilla Bug #730162 - TPS/TKS token enrollment failure in FIPS mode
  (hsm+NSS). (jmagne)

* Thu Aug 11 2011 Christina Fu <cfu@redhat.com> 8.1.0-7
- Bugzilla Bug #724848 - CC_LAB_EVAL: none-FIPS ciphers allowed in CC mode

* Tue Jun 7 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-6
- Bugzilla Bug #703324 - rhcs81beta - uri redirection from / to /ca/ee/ca
  with blank page if Java security manager is active
- Bugzilla Bug #708297 - Incorrect info shown for Server Version in pkiconsole

* Tue May 10 2011 Ade Lee <alee@redhat.com> 8.1.0-5
- Bugzilla Bug #703324 - rhcs81beta - uri redirection from / to /ca/ee/ca
  with blank page if Java security manager is active (alee)
- Bugzilla Bug #649910 - Console: an auditor or agent can be added to an
  administrator group. (jmagne)

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-4
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Wed Jan 5 2011 Ade Lee <alee@redhat.com> 8.1.0-3
- Bugzilla Bug #223346 - Two conflicting ACL list definitions in source repository

* Tue Dec 14 2010 Ade Lee <alee@redhat.com> 8.1.0-2
- Bugzilla Bug #663116 - Update nuxwdog dependencies

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Mon Nov 9 2009 Ade Lee <alee@redhat.com> 8.0.0-21
- Bugzilla Bug #518123 - Prompt for passwords if password.conf is removed

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-20
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-19
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-18
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-17
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Fri Jun 19 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-16
- Bugzilla Bug #506867 -  Provide custom error page for HTTP STATUS 500

* Mon Jun 15 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-15
- Bugzilla Bug #502908 -  Current page not found handling is a Cat 2 finding
  with the Tomcat STIG

* Sat May 30 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-14
- Bugzilla Bug #476782 -  Create "pkiuser" with a predetermined
  system "UID" and "GID" . . .

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-13
- Bugzilla Bug #499030 -  Beta 2 Release

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-12
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-11
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Mon Feb 16 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #485790 -  Need changes made to spec files in various
  packages to be able to build in koji/brew

* Sat Feb 14 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-9
- Bugzilla Bug #250874 -Change spec file dependencies to rely on latest
  versions of components (NSPR, NSS, JSS, MOD_NSS)

* Thu Feb 12 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-8
- Bugzilla Bug #483699 -  problem with the epoch in the spec file causes
  build to fail

* Tue Jan 27 2009 Ade Lee <alee@redhat.com> 8.0.0-7
- Bugzilla Bug 480679 - Integrate selinux into framework

* Wed Dec 10 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-6
- Bugzilla Bug #475895 - Parameterize the initial login shell

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-5
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Fri Jun 8 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- bugzilla bug #243480 - added legacy upgrade path

* Tue Jun 5 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-2
- bugzilla bug #242575 - Made numerous changes to spec file.

* Mon May 21 2007 Kevin McCarthy <kmccarth@redhat.com> 8.0.0-1
- Bump to version 8.0.

* Fri May 04 2007 Kevin McCarthy <kmccarth@redhat.com> 7.3.0-10
- Fix for RHEL5.

* Tue Apr 10 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-9
- Revised LICENSE file.
- Bumped Release Number.

* Thu Apr 5 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-8
- Updated LICENSE file.
- Bumped Release Number.

* Thu Mar 29 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-7
- Bumped Release Number.

* Wed Mar 28 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-6
- Made package URL contingent upon distribution.
- Bumped Release Number.

* Fri Mar 9 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-5
- Generalized spec to handle el5 or later.

* Wed Feb 22 2006 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Renamed "rpm.template" to "pki.template". Filled in Solaris section.

* Mon Feb 20 2006 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Separated template into Linux, Solaris, and Changelog sections.

* Mon Dec 5 2005 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Initial RPM template.

